﻿function addOrUpdateBookToCart(bookID, bookName, quantity, cost) {
    // Get the cart data from the cookie
    var stringData = $.cookie("cartData");

    // If the data does not exist then create an empty array, otherwise parse it.
    if(stringData == undefined)
        data = [];
    else
        data = $.parseJSON(stringData);

    // loop through existing books and remove the book we are trying to insert (overwrite it)
    for(var i = 0; i < data.length; i++)
    {
        if (data[i].ID == bookID) {
            data.splice(i, 1);
        }
    }

    // Create the new data for the book we are inserting
    var bookData = {};
    bookData.ID = bookID;
    bookData.name = bookName;
    bookData.quantity = quantity;
    bookData.cost = cost;

    if (quantity > 0)
        data.push(bookData);

    // Sort the books by their name.
    data.sort(function (a, b) { return a.name.localeCompare(b.name); })

    $.cookie("cartData", JSON.stringify(data), { path: '/' });
}

// This is similar to the function above but will add to the quantity if the item exists.
function AddCartItem(id, title, cost, quantity) {
    var stringData = $.cookie("cartData");

    if (stringData == undefined)
        data = [];
    else
        data = $.parseJSON(stringData);

    var existingQuantity = 0;
    for (var i = 0; i < data.length; i++) {
        if (data[i].ID == id) {
            existingQuantity = data[i].quantity;
            data.splice(i, 1);
        }
    }

    addOrUpdateBookToCart(id, title, existingQuantity + quantity, cost);

    buildCart();
}

$(document).ready(function () {
    // Set the default cookie path an show the cart.
    $.cookie.defaults = { path: '/', expires: 365 };
    buildCart();
})

// This function will show the cart with all of its contents.
// When an item is added this will be called again to update the html.
function buildCart() {
    var stringData = $.cookie("cartData");

    if (stringData == undefined)
        data = [];
    else
        data = $.parseJSON(stringData);

    $('.cart-item-area').empty();
    var total = 0;
    for (var i = 0; i < data.length; i++) {
        var itemTotal = parseFloat(data[i].cost) * parseFloat(data[i].quantity);
        $('.cart-item-area').append(getCartItemElem(data[i].ID, data[i].name, data[i].cost, data[i].quantity));
        total += itemTotal;
    }

    $('.cart-total-amt').text("Total: $" + total.toFixed(2));

    if(data.length > 0)
    {
        $('.cart-controls').show();
        $('.empty-cart').hide();
    } else {
        $('.cart-controls').hide();
        $('.empty-cart').show();
    }
}

// Remove overything from the cart.
function clearCart() {
    var stringData = $.cookie("cartData");

    if (stringData == undefined)
        data = [];
    else
        data = $.parseJSON(stringData);

    for (var i = 0; i < data.length; i++) {
            data.splice(i, 1);
    }

    $.cookie("cartData", JSON.stringify(data), { path: '/' });
    buildCart();
}

// This will generate the html for a given cart item.
function getCartItemElem(id, title, cost, quantity) {
    var cartItem = $('<div>').addClass('cart-item');

    var itemRemove = $('<div>').addClass('cart-item-remove')
    .append($('<i>').addClass('glyphicon glyphicon-remove text-danger'));
    cartItem.append(itemRemove);

    var itemTitle = $('<div>').addClass('cart-item-title')
    .append($('<a>').text(title).prop('href', '/Website/Book/'+id));
    cartItem.append(itemTitle);

    itemRemove.click(function () {
        $(this).closest('.cart-item').remove();
        addOrUpdateBookToCart(id, title, 0, cost);
        buildCart()
    });

    cartItem.append($('<div>').addClass('clearfix'));

    var itemTotal = parseFloat(cost) * parseFloat(quantity);
    var total = $('<div>').addClass('cart-item-cost pull-right').text('$'+itemTotal.toFixed(2))
    cartItem.append(total);

    var quantityInput = $('<input>').addClass('form-control cart-quantity text-center cart-item-quantity').prop('value', quantity);
    var quantity = $('<div>').text('Quantity: ')
        .append(quantityInput);

    quantityInput.change(function () {
        addOrUpdateBookToCart(id, title, parseInt($(this).val()), cost);
        buildCart()
    });

    cartItem.append(quantity);

    return cartItem;
}


              